# ChaiPy

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/chaipy)
![PyPI](https://img.shields.io/pypi/v/chaipy)

A developer interface for creating Chat AIs for the Chai app.

## Install

You can install chai using pip

    $ pip install -U chaipy

## Documentation

An API guide is available on the [Chai website](https://chai.ml/doc/python-api)

## Testing

Tests can be run using [pytest](http://pytest.org/).

    $ python -m pytest

## Requirements

Python 3.7 or later is required.

## Get Involved

Speak to us on [Whatsapp](https://chat.whatsapp.com/Btbz9tYOpyG72oqI4NfGE1)

Come join us on [Discord](https://discord.gg/YfrVwBtYWb)!
